#!/bin/bash
#=========================================================================
#
# USAGE
#  ./GET_FORCING.sh $BEG_DATE $END_DATE $SCRATCHDIR $FORC_DIR
#
# BEG_DATE     : begin date of forcing (YYYYMMDDHH)
# END_DATE     : end date of forcing
# SCRATCHDIR   : directory where forcings are stored temporally
# FORC_DIR     : forcing directory on hendrix
# days_FC      : the days of a deterministic forecast
#
# Download forcing files from hendrix
#
#=========================================================================
#
#set -x

BEG_DATE=$1
END_DATE=$2
SCRATCHDIR=$3
FORC_DIR=$4
days_FC=${5:-0}

#
RUNDIR=$(pwd)
#
#=========================================================================
#
# for use of srun
export I_MPI_PMI_LIBRARY=/usr/lib64/libpmi.so
#
# transfer
echo  Getting forcings from ${BEG_DATE} to ${END_DATE}
#
mkdir -p $SCRATCHDIR
cd $SCRATCHDIR
#
# remove old files
rm -f FORCING_*.nc
# analysis forcing
forc_files="mget -c"
CDATE=$BEG_DATE
while [ ${CDATE} -le ${END_DATE} ]; do
  [ ! -f FORCING_${CDATE}.nc ] && forc_files="$forc_files ${FORC_DIR}/FORCING_${CDATE}.nc"
  CDATE=`$RUNDIR/ADD_DATE.sh ${CDATE} +1day`
done
# forecast forcing
if [ $days_FC -gt 0 ]; then
  CDATE=$BEG_DATE
  while [ ${CDATE} -le ${END_DATE} ]; do
    if [ ! -d FC_${CDATE} ]; then
      mkdir -p FC_${CDATE}
      forc_files="$forc_files; lcd $SCRATCHDIR/FC_${CDATE}; mget -c ${FORC_DIR}/FC_${CDATE:0:8}*/FORCING_*.nc"
    fi
    CDATE=`$RUNDIR/ADD_DATE.sh ${CDATE} +1day`
  done
fi
forc_files="$forc_files; quit"
#
cat > .ftp.cmd << EOF
#!/bin/bash
#SBATCH -J transfer
#SBATCH -p transfert
#SBATCH -N 1
#SBATCH -n 1
#SBATCH -o transfer_%j
#SBATCH -e transfer_%j

lftp hendrix -e '$forc_files'
EOF

chmod u+x .ftp.cmd
jobid_ftp=`sbatch .ftp.cmd`
#
jobid_ftp=`echo $jobid_ftp | awk '{print $4}'`
DT=2; while [ ! -z "`squeue --job $jobid_ftp 2> /dev/null | grep $jobid_ftp`" ]; do sleep $DT; done
#
cd $RUNDIR
