#!/bin/bash
#=========================================================================
#
# USAGE
#  ./GET_OBS.sh $BEG_DATE $END_DATE $SCRATCHDIR $OBS_DIR
#
# BEG_DATE     : the begin date of observation (YYYYMMDDHH)
# BEG_DATE     : the end date of observation (YYYYMMDDHH)
# SCRATCHDIR   : directory where forcings are stored temporally
# OBS_DIR      : observation directory on hendrix
#
# Download observation files from hendrix
#
#=========================================================================
#
BEG_DATE=$1
END_DATE=$2
SCRATCHDIR=$3
OBS_DIR=$4

#
RUNDIR=$(pwd)
#
#=========================================================================
#
# for use of srun
export I_MPI_PMI_LIBRARY=/usr/lib64/libpmi.so
#
# transfer
echo  Getting observations from ${BEG_DATE} to ${END_DATE}
#
mkdir -p $SCRATCHDIR
cd $SCRATCHDIR
#
# remove old files
rm -f CANARI_NATURE_*.DAT
#
obs_files="mget -c"
CDATE=$BEG_DATE
while [ ${CDATE} -le ${END_DATE} ]; do
  CDATE=`$RUNDIR/ADD_DATE.sh ${CDATE} +1day`
  OBSFORMAT=`echo ${CDATE:2} | sed 's/./H&/7'`
  [ ! -f CANARI_NATURE_${OBSFORMAT}.DAT ] && obs_files="$obs_files ${OBS_DIR}/CANARI_NATURE_${OBSFORMAT}.DAT"
done
obs_files="$obs_files; quit"
#
cat > .ftp.cmd << EOF
#!/bin/bash
#SBATCH -J transfer
#SBATCH -p transfert
#SBATCH -N 1
#SBATCH -n 1
#SBATCH -o transfer_%j
#SBATCH -e transfer_%j

lftp hendrix -e '$obs_files'
EOF

chmod u+x .ftp.cmd
jobid_ftp=`sbatch .ftp.cmd`
#
jobid_ftp=`echo $jobid_ftp | awk '{print $4}'`
DT=2; while [ ! -z "`squeue --job $jobid_ftp 2> /dev/null | grep $jobid_ftp`" ]; do sleep $DT; done
#
cd $RUNDIR
