#!/bin/bash
#=========================================================================
#
# USAGE
#  ./PUT_RESULT.sh $BEG_ID:$END_ID $BEG_DATE:$END_DATE:$RESTART_DATE $SCRATCHDIR/$EXP:$RESDIR $TYP $days_FC wait_for_finish
#
# BEG_ID       : the begin id of a job
# END_ID       : the end id of a job
# BEG_DATE     : the begin date of a batch run
# END_DATE     : the end date of a batch run
# RESTART_DATE : the date for restart
# SCRATCHDIR   : directory where results are stored during the run
# RESDIR       : storing directory on hendrix
#
#=========================================================================
#

BEG_ID=`echo $1 | awk '{split($1, f, ":"); print f[1]}'`
END_ID=`echo $1 | awk '{split($1, f, ":"); print f[2]}'`
BEG_DATE=`echo $2 | awk '{split($1, f, ":"); print f[1]}'`
END_DATE=`echo $2 | awk '{split($1, f, ":"); print f[2]}'`
RESTART_DATE=`echo $2 | awk '{split($1, f, ":"); print f[3]}'`
SCRATCHDIR=`echo $3 | awk '{split($1, f, ":"); print f[1]}'`
RESDIR=`echo $3 | awk '{split($1, f, ":"); print f[2]}'`
TYP=$4
days_FC=${5:-0}
wait_for_finish=${6:-0}

RUNDIR=$(pwd)

#
#=========================================================================
#
# check if TRIP is used
LTRIP=`grep "LOASIS *= *T" OPTIONS.nam_0 | wc -l`
#
#=========================================================================
#
# for use of srun
export I_MPI_PMI_LIBRARY=/usr/lib64/libpmi.so

#
cd $SCRATCHDIR

# copy the restart files because we do not wait for the finish of the transfer
IRUN=$BEG_ID
while [ $IRUN -le $END_ID ]; do  
  mv -f PREP_$IRUN.nc PREP_${RESTART_DATE}_$IRUN.nc
  if [ $LTRIP -eq 1 ]; then
    mv -f TRIP_PREP_$IRUN.nc TRIP_PREP_${RESTART_DATE}_$IRUN.nc
    mv -f lsm_$IRUN.nc lsm_${RESTART_DATE}_$IRUN.nc
    mv -f trip_$IRUN.nc trip_${RESTART_DATE}_$IRUN.nc
  fi
  IRUN=$((IRUN+1))
done
#
echo "transfer the results ($BEG_DATE - $END_DATE) to hendrix with archiving and compressing on the fly"
#
FTPCMD=.ftp.cmd.${BEG_DATE}-${END_DATE}.$TYP
cat > ${FTPCMD} << EOF
#!/bin/bash
#SBATCH -J transfer
#SBATCH -p transfert
#SBATCH -N 1
#SBATCH -n 1
#SBATCH -o transfer_%j
#SBATCH -e transfer_%j

BEG_DATE=\$1
END_DATE=\$2
RESTART_DATE=\$3
LTRIP=\$4
RESDIR=\$5
RUNDIR=\$6
TYP=\$7
days_FC=\$8

FILELIST=.filelist.\${BEG_DATE}-\${END_DATE}.$TYP

# RESTART files
rm -f \${FILELIST}
ls -1 --indicator-style=none PREP_\${RESTART_DATE}_*.nc >> \${FILELIST} 2>/dev/null
if [ \$LTRIP -eq 1 ]; then
  ls -1 --indicator-style=none TRIP_PREP_\${RESTART_DATE}_*.nc >> \${FILELIST} 2>/dev/null
  ls -1 --indicator-style=none lsm_\${RESTART_DATE}_*.nc >> \${FILELIST} 2>/dev/null
  ls -1 --indicator-style=none trip_\${RESTART_DATE}_*.nc >> \${FILELIST} 2>/dev/null
fi
tar cf - -T \${FILELIST} | pigz -qf | lftp hendrix -e "mkdir -fp \$RESDIR; put -c /dev/stdin -o \$RESDIR/RESTART_\${RESTART_DATE}.tar.gz; quit"
[ \$? -eq 0 ] && xargs rm < \${FILELIST}

# ISBA_DIAGNOSTICS files
rm -f \${FILELIST}
CDATE=\$BEG_DATE
while [ \$CDATE -le \$END_DATE ]; do
  ls -1 --indicator-style=none ISBA_DIAGNOSTICS_\${CDATE:0:8}_*.nc >> \${FILELIST} 2>/dev/null
  CDATE=\`\$RUNDIR/ADD_DATE.sh \$CDATE +1day\`
  [ "\$TYP" = "EKF" -o "\$TYP" = "ENKF" ] && ls -1 --indicator-style=none ISBA_DIAGNOSTICS_\${CDATE:0:10}_*.nc >> \${FILELIST} 2>/dev/null
done
tar cf - -T \${FILELIST} | pigz -qf | lftp hendrix -e "mkdir -fp \$RESDIR; put -c /dev/stdin -o \$RESDIR/ISBA_DIAGNOSTICS_\${BEG_DATE}-\${END_DATE}.tar.gz; quit"
[ \$? -eq 0 ] && xargs rm < \${FILELIST}

# ISBA_DIAG_CUMUL files
rm -f \${FILELIST}
CDATE=\$BEG_DATE
while [ \$CDATE -le \$END_DATE ]; do
  ls -1 --indicator-style=none ISBA_DIAG_CUMUL_\${CDATE:0:8}_*.nc >> \${FILELIST} 2>/dev/null
  CDATE=\`\$RUNDIR/ADD_DATE.sh \$CDATE +1day\`
  [ "\$TYP" = "EKF" -o "\$TYP" = "ENKF" ] && ls -1 --indicator-style=none ISBA_DIAG_CUMUL_\${CDATE:0:10}_*.nc >> \${FILELIST} 2>/dev/null
done
tar cf - -T \${FILELIST} | pigz -qf | lftp hendrix -e "mkdir -fp \$RESDIR; put -c /dev/stdin -o \$RESDIR/ISBA_DIAG_CUMUL_\${BEG_DATE}-\${END_DATE}.tar.gz; quit"
[ \$? -eq 0 ] && xargs rm < \${FILELIST}

# ISBA_PROGNOSTIC files
rm -f \${FILELIST}
CDATE=\$BEG_DATE
while [ \$CDATE -le \$END_DATE ]; do
  ls -1 --indicator-style=none ISBA_PROGNOSTIC_\${CDATE:0:8}_*.nc >> \${FILELIST} 2>/dev/null
  CDATE=\`\$RUNDIR/ADD_DATE.sh \$CDATE +1day\`
  [ "\$TYP" = "EKF" -o "\$TYP" = "ENKF" ] && ls -1 --indicator-style=none ISBA_PROGNOSTIC_\${CDATE:0:10}_*.nc >> \${FILELIST} 2>/dev/null
done
tar cf - -T \${FILELIST} | pigz -qf | lftp hendrix -e "mkdir -fp \$RESDIR; put -c /dev/stdin -o \$RESDIR/ISBA_PROGNOSTIC_\${BEG_DATE}-\${END_DATE}.tar.gz; quit"
[ \$? -eq 0 ] && xargs rm < \${FILELIST}

# ISBA_ANALYSIS files
if [ "\$TYP" = "EKF" -o "\$TYP" = "ENKF" ]; then
  rm -f \${FILELIST}
  CDATE=\$BEG_DATE
  while [ \$CDATE -le \$END_DATE ]; do
    CDATE=\`\$RUNDIR/ADD_DATE.sh \$CDATE +1day\`
    ls -1 --indicator-style=none ISBA_ANALYSIS_\${CDATE:0:10}_*.nc >> \${FILELIST} 2>/dev/null
  done
  tar cf - -T \${FILELIST} | pigz -qf | lftp hendrix -e "mkdir -fp \$RESDIR; put -c /dev/stdin -o \$RESDIR/ISBA_ANALYSIS_\${BEG_DATE}-\${END_DATE}.tar.gz; quit"
  [ \$? -eq 0 ] && xargs rm < \${FILELIST}
fi

# TRIP files
if [ \$LTRIP -eq 1 ]; then
  rm -f \${FILELIST}
  CDATE=\$BEG_DATE
  while [ \$CDATE -le \$END_DATE ]; do
    ls -1 --indicator-style=none TRIP*_\${CDATE:0:8}_*.nc >> \${FILELIST} 2>/dev/null
    CDATE=\`\$RUNDIR/ADD_DATE.sh \$CDATE +1day\`
  done
  tar cf - -T \${FILELIST} | pigz -qf | lftp hendrix -e "mkdir -fp \$RESDIR; put -c /dev/stdin -o \$RESDIR/TRIP_\${BEG_DATE}-\${END_DATE}.tar.gz; quit"
  [ \$? -eq 0 ] && xargs rm < \${FILELIST}
fi

# Deterministic forecast
if [ \$days_FC -gt 0 ]; then
  CDATE=\$BEG_DATE
  while [ \$CDATE -le \$END_DATE ]; do
    # wait for finish
    if [ -f FC_\${CDATE}/FC_JOB.LOG ]; then
      FC_JOB_LOG=\`head -n 1 FC_\${CDATE}/FC_JOB.LOG\`
      STATE1=\`grep 'State                : ' \${FC_JOB_LOG}\`
      STATE2=\`echo "\$STATE1" | grep 'State                : COMPLETED'\`
      if [ ! -z "\$STATE2" ]; then
        # archive and upload
        ls -1 --indicator-style=none FC_\${CDATE}/*.nc > \${FILELIST} 2>/dev/null
        tar cf - -T \${FILELIST} | pigz -qf | lftp hendrix -e "mkdir -fp \$RESDIR; put -c /dev/stdin -o \$RESDIR/FC_\${CDATE}.tar.gz; quit"
        [ \$? -eq 0 ] && rm -rf FC_\${CDATE}
    
        CDATE=\`\$RUNDIR/ADD_DATE.sh \$CDATE +1day\`
      else
        if [ ! -z "\$STATE1" ]; then
          # job finished but failed
          CDATE=\`\$RUNDIR/ADD_DATE.sh \$CDATE +1day\`
        else
          # job is not finished
          sleep 2
        fi
      fi
    else
      # job is not finished
      sleep 2
    fi
  done
fi

EOF
#
chmod u+x ${FTPCMD}
jobid_ftp=`sbatch ${FTPCMD} $BEG_DATE $END_DATE $RESTART_DATE $LTRIP $RESDIR $RUNDIR $TYP $days_FC`
#
if [ $wait_for_finish -ne 0 ]; then
  jobid_ftp=`echo $jobid_ftp | awk '{print $4}'`
  DT=2; while [ ! -z "`squeue --job $jobid_ftp 2> /dev/null | grep $jobid_ftp`" ]; do sleep $DT; done
fi
#
cd $RUNDIR
#
